@@ -1,21 +1,25 @@
-BarChart <-
-function(x=NULL, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"), 
+BarChart <- function(x=NULL, y=NULL, data=mydata, n.cat=getOption("n.cat"), 
 
-         fill=getOption("fill.bar"),
-         stroke=getOption("stroke.bar"),
-         bg=getOption("bg"),
-         grid=getOption("grid"),
-         box=getOption("box"),
+         by=NULL, by1=NULL,
+         n.row=NULL, n.col=NULL, aspect="fill",
+
+         fill=getOption("bar.fill"),
+         stroke=getOption("bar.stroke"),
+         bg.fill=getOption("bg.fill"),
+         bg.stroke=getOption("bg.stroke"),
          trans=NULL,
 
          colors=c("rainbow", "terrain", "heat"),
 
-         horiz=FALSE, over.grid=FALSE, addtop=0.05,
+         horiz=FALSE, addtop=0.05,
          gap=NULL, proportion=FALSE,
          
-         xlab=NULL, ylab=NULL, main=NULL,
-         cex.axis=0.75, axes="gray30",
-         value.labels=NULL, label.max=20, rotate.x=0, rotate.y=0, offset=0.5,
+         xlab=NULL, ylab=NULL, main=NULL, cex.names=0.70,
+         cex.lab=0.84, cex.axis=getOption("cex.axis"),
+         value.labels=NULL, label.max=20,
+         rotate.x=getOption("rotate.x"),
+         rotate.y=getOption("rotate.y"),
+         offset=getOption("offset"),
 
          beside=FALSE, low.fill=NULL, hi.fill=NULL, 
 
@@ -23,26 +27,28 @@ function(x=NULL, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
          legend.horiz=FALSE, 
 
          quiet=getOption("quiet"),
-         width=4.5, height=4.5, pdf=FALSE, ...)  {
+         width=5, height=4.5, pdf.file=NULL, ...)  {
 
 
   if (missing(colors)) 
-    colors <- getOption("colors")
+    colors <- getOption("theme")
   else
     colors <- match.arg(colors)
 
+  Trellis <- ifelse(!missing(by1), TRUE, FALSE)
+  do.plot <- TRUE
+
   if (!is.null(fill)) {
     for (i in 1:length(fill))
       if (fill[i] == "off") fill[i] <- "transparent"
   }
   for (i in 1:length(stroke))
     if (stroke[i] == "off") stroke[i] <- "transparent"
-  if (bg == "off") bg <- "transparent"
-  if (grid == "off" ) grid <- "transparent"
-  if (box == "off") box <- "transparent"
+  if (bg.fill == "off") bg.fill <- "transparent"
+  if (bg.stroke == "off") bg.stroke <- "transparent"
 
   if (missing(stroke))  # default black border unless dark bg
-    if (sum(col2rgb(bg))/3 > 80) stroke <- "black"
+    if (sum(col2rgb(bg.fill))/3 > 80) stroke <- "black"
 
   dots <- list(...)  # check for deprecated/changed parameters
   if (length(dots) > 0) {
@@ -77,9 +83,25 @@ function(x=NULL, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
           "color options dropped the  color. prefix\n",
           "eg., fill, instead of color.fill.\n\n")
       }
-      if (names(dots)[i] == "pdf.file") {
+      if (names(dots)[i] == "over.grid") {
         cat("\n"); stop(call.=FALSE, "\n","------\n",
-          "pdf.file  changed to  pdf, either TRUE or FALSE\n\n")
+          "over.grid  option removed\n\n")
+      }
+      if (names(dots)[i] == "pdf") {
+        cat("\n"); stop(call.=FALSE, "\n","------\n",
+          "pdf  changed to  pdf.file\n\n")
+      }
+      if (names(dots)[i] == "box") {
+        cat("\n"); stop(call.=FALSE, "\n","------\n",
+          "option  box  is renamed  bg.stroke\n\n")
+      }
+      if (names(dots)[i] == "bg") {
+        cat("\n"); stop(call.=FALSE, "\n","------\n",
+          "option  bg  is renamed  bg.fill\n\n")
+      }
+      if (names(dots)[i] == "axes") {
+        cat("\n"); stop(call.=FALSE, "\n","------\n",
+          "option  axes  is renamed  values.stroke\n\n")
       }
     }
   }
@@ -148,7 +170,7 @@ function(x=NULL, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
       #   which leads to in.global FALSE
       #if (exists(by.name, where=.GlobalEnv)) in.global <- TRUE
 
-      # see if var exists in data frame, if x not in Global Env or function call 
+      # see if var exists in data frame, if x not in global Env or function call 
       if (!in.global) .xcheck(by.name, df.name, data)
       #if (!in.global && !in.call) .xcheck(by.name, df.name, data)
       if (!in.global)
@@ -164,6 +186,7 @@ function(x=NULL, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
 
 
     # evaluate y
+    #-------------
     if (!missing(y)) {
 
       # get actual variable name before potential call of data$x
@@ -171,10 +194,10 @@ function(x=NULL, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
       options(yname = y.name)
 
       # get conditions and check for data existing
-        xs <- .xstatus(y.name, df.name, quiet)
-        in.global <- xs$ig 
+      xs <- .xstatus(y.name, df.name, quiet)
+      in.global <- xs$ig 
 
-      # see if var exists in data frame, if x not in Global Env or function call 
+      # see if var exists in data frame, if x not in global Env or function call 
       if (!in.global) .xcheck(y.name, df.name, data)
       if (!in.global)
         y.call <- eval(substitute(data$y))
@@ -187,6 +210,37 @@ function(x=NULL, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
     else
       y.call <- NULL
 
+    
+    # evaluate by1
+    #-------------
+    if (!missing(by1)) {
+
+      # get actual variable name before potential call of data$x
+      by1.name <- deparse(substitute(by1))
+      options(by1name = by1.name)
+
+      # get conditions and check for data existing
+      xs <- .xstatus(by1.name, df.name, quiet)
+      in.global <- xs$ig
+
+      # see if var exists in data frame, if x not in global Env or function call
+      if (!missing(x) && !in.global)
+        .xcheck(by1.name, df.name, data)
+
+      if (!in.global)
+        by1.call <- eval(substitute(data$by1))
+      else {  # vars that are function names get assigned to global
+        by1.call <- by1
+        if (is.function(by1.call)) by1.call <- eval(substitute(data$by1))
+      }
+
+      if (!is.factor(by1.call)) by1.call <- factor(by1.call)
+    }
+
+    else
+     by1.call <- NULL
+
+
 
     if (length(unique(na.omit(x.call))) == 1) { 
       cat("\n"); stop(call.=FALSE, "\n","------\n",
@@ -196,41 +250,59 @@ function(x=NULL, y=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
         " unique value\n\n")
     }
 
+
+  # -----------  x, y, by and size variables established ------------
+  # -----------------------------------------------------------------
+
     # do the analysis
 
-    if (pdf)
-      pdf.fnm <- paste("BarChart_", x.name, ".pdf", sep="") 
-    else
-      pdf.fnm <- NULL
-    .opendev(pdf.fnm, width, height)
-
-    orig.params <- par(no.readonly=TRUE)
-    on.exit(par(orig.params))
-
-    bc <- .bc.main(x.call, y.call, by.call,
-         fill, stroke, bg, grid, box, trans, colors,
-         horiz, over.grid, addtop, gap, proportion, xlab, ylab, main,
-         value.labels, label.max,
-         cex.axis, axes, rotate.x, rotate.y, offset, beside, low.fill, hi.fill,
-         legend.title, legend.loc, legend.labels, legend.horiz, quiet, ...)
-
-    if (is.null(pdf)) {
-      dev.off()
-      if (!quiet) .showfile(pdf.fnm, "barchart")
+    if (Trellis && do.plot) {
+      .bar.lattice(x.call, by1.call, by2=NULL, n.row, n.col, aspect, prop=FALSE,
+                   fill, stroke, bg.fill, bg.stroke, trans, 
+                   size.pt=NULL, xlab, ylab, main, cex.lab, cex.axis,
+                   rotate.x, rotate.y, width, height, pdf.file,
+                   segments.x=NULL, breaks=NULL, c.type="bar")
     }
 
-    invisible(bc)
+    else {
+
+      if (!is.null(pdf.file))
+        pdf.fnm <- paste("BarChart_", x.name, ".pdf", sep="") 
+      else
+        pdf.fnm <- NULL
+      .opendev(pdf.fnm, width, height)
+
+      bc <- .bc.main(x.call, y.call, by.call,
+           fill, stroke, bg.fill,
+           bg.stroke, trans, colors,
+           horiz, addtop, gap, proportion, xlab, ylab, main, cex.lab,
+           value.labels, label.max,
+           cex.axis, cex.names, rotate.x, rotate.y, offset,
+           beside, low.fill, hi.fill,
+           legend.title, legend.loc, legend.labels, legend.horiz, quiet, ...)
+
+      if (!is.null(pdf.file)) {
+        dev.off()
+        if (!quiet) .showfile(pdf.fnm, "barchart")
+      }
+
+      invisible(bc)
+    }  # end !Trellis
   }
   
 
-  else
+  else {
+
     bc.data.frame(data, n.cat,
-      fill, stroke, bg, grid, box, trans, colors,
-      horiz, over.grid, addtop, gap, proportion, xlab, ylab, main,
+      fill, stroke, bg.fill, bg.stroke,
+      trans, colors,
+      horiz, addtop, gap, proportion, xlab, ylab, main, cex.lab,
       value.labels, label.max,
-      cex.axis, axes, rotate.x, rotate.y, offset, beside, low.fill, hi.fill,
+      cex.axis, cex.names, rotate.x, rotate.y, offset,
+      beside, low.fill, hi.fill,
       legend.title, legend.loc, legend.labels, legend.horiz, quiet,
-      width, height, pdf, ...)
+      width, height, pdf.file, ...)
+  }
 
 }
 
