@@ -21,7 +21,7 @@ function(topic=NULL, width=4.5, height=4.5) {
     txt <- "For more help on a function, enter"
     h2 <- paste(txt, " ? in front of its name:  ?", fname, sep="")
 
-    if (getOption("colors") != "gray") 
+    if (!(getOption("theme") %in% c("lightbronze", "gray"))) 
       col.sep <- "lightsteelblue"
     else
       col.sep <- "gray50"
@@ -46,8 +46,8 @@ function(topic=NULL, width=4.5, height=4.5) {
   # convert topic to all lowercase letters
   if (!is.null(topic)) topic <- tolower(topic)
 
-  if (getOption("colors") != "gray") {
-    col.rect <- getOption("col.fill.pt")
+  if (!(getOption("theme") %in% c("lightbronze", "gray"))) { 
+    col.rect <- getOption("col.pt.fill")
     col.line <- "lightsteelblue"
   }
   else {
@@ -65,7 +65,7 @@ function(topic=NULL, width=4.5, height=4.5) {
 
   t0 <- "Help Topics for lessR"
 
-  fsys <- bquote(paste(bold("Help(global)"), "  System level settings, such as a color theme for graphics"))
+  fsys <- bquote(paste(bold("Help(style)"), "  System level settings, such as a color theme for graphics"))
   fcsv <- bquote(paste(bold("Help(data)"), "  Create a data file from Excel or similar application"))
   frw <- bquote(paste(bold("Help(Read)"), " and ", bold("Help(Write)"), "  Read or write data to or from a file"))
   flib <- bquote(paste(bold("Help(library)"), "  Access sets of functions called packages"))
@@ -317,35 +317,36 @@ function(topic=NULL, width=4.5, height=4.5) {
   }
 
 
-  else if (topic %in% c("system", "set", "theme", "global")) {
-  t0 <- "Global Settings"
+  else if (topic %in% c("system", "global", "set", "theme", "style")) {
+  t0 <- "style Settings"
 
-  f1 <- bquote(paste(bold("global"), "  all lessR system settings such as a color theme"))
+  f1 <- bquote(paste(bold("style"), "  all lessR system settings such as a color theme"))
   f2 <- bquote(paste(bold("showColors"), "  lessR function to illustrate all color names"))
 
   t1 <- "
-  The lessR function global provides global settings for lessR functions.
-  Set the color theme for the graphics functions. The default color global is
-  \"dodgerblue\", with possibilities of \"gray\", \"green\", \"gold\", \"rose\", \"red\", 
-  \"darkred\", \"brown\", \"purple\", \"sienna\", \"white\", \"orange.black\" and
-  \"gray.black\".  Example:
-      > global(colors=\"gray\") 
-  Set the transparency level of bars and plotted points with the
-  trans.fill.bar and trans.fill.pt options, or just trans.
-  Turn off grid lines with grid=\"off\".
-  Change or remove background color with bg, such as bg=\"off\".
+  The lessR function style provides style settings for lessR functions.
+  Set the color theme for the graphics functions. The default color style is
+  \"lightbronze\". Other themes are of \"gray\", \"green\", \"darkgreen\", \"gold\",
+  \"rose\", \"red\", \"darkred\", \"brown\", \"purple\", \"sienna\", \"white\",
+  and \"orange\". Can further modify with sub.theme.  Example:
+      > style(\"gold\", sub.theme=\"black\") 
+  Setting a style resets all attributes. Or set individual attributes,
+  or more grouped attributes with sub.theme, which cumulate until reset. 
+  For example, to convert the default theme to gray scale, 
+      > style(device.fill=\"white\")
+  which sets the entire graphics window to a white background.
 
   Levels of a categorical variable may be encoded with numerical digits,
   such as 0 for Male and 1 for Female. R is obliged to interpret numerical
   variables as numeric.  One option is to redefine these variables as
   factors [see Help(edit)]. Or set the value of the lessR option n.cat.
-      > global(n.cat=3)
+      > style(n.cat=3)
   Here any numerical variable with just 3 unique, equally spaced interval 
   values or less is interpreted as a categorical variable. The default
   value of n.cat is 8, and applies to ScatterPlot and SummaryStats.
 
-  To see all available global options, enter the following.
-      > global(show=TRUE)
+  To see all available style options, enter the following.
+      > style(show=TRUE)
   To see all the R named colors, enter the following.
       > showColors()
   "
@@ -357,7 +358,7 @@ function(topic=NULL, width=4.5, height=4.5) {
   #lines(c(5,90), c(80,80), col=col.line)
   text(0,47, label=t1, adj=0)
 
-  help.more("global", 7)
+  help.more("style", 7)
   }
 
 
@@ -376,7 +377,7 @@ function(topic=NULL, width=4.5, height=4.5) {
   color theme, here for variable Y. Use Histogram or hs.
       > Histogram(Y)
   Specify the gray-scale color theme, a title, and a label for the x-axis.
-      > global(\"gray\")
+      > style(\"gray\")
       > Histogram(Y, main=\"My Title\", xlab=\"Y (mm)\")
   Specify bins, begin at 60 with a bin width of 10. Can also specify bin.end.
       > Histogram(Y, bin.start=60, bin.width=10)
@@ -429,10 +430,10 @@ function(topic=NULL, width=4.5, height=4.5) {
       > Ycount <- table(mydata$Y)
       > pareto.chart(Ycount$freq)
 
-  Can replace the variable name such as Y with a list of multiple variables,
-  such as c(Salary, Years) or Salary:Years, or an entire data frame. The
-  default data frame is mydata. Here do a bar chart of all non-numeric
-  variables in mydata.
+  Can replace a variable name with a list of variables, e.g., c(Salary, Years)
+  or Salary:Years, or an entire data frame. The default data frame is mydata.
+  Here do a bar chart of all categorical variables in mydata, those that are
+  non-numeric, or less than n.cat=8 equally spaced integer values.
       > BarChart()
   "
 
@@ -456,7 +457,7 @@ function(topic=NULL, width=4.5, height=4.5) {
   t1 <- "
   The lessR function LineChart, or lc, generates a line chart with values
   ordered along some dimension such as time. If the data do not have a 
-  pronounced trend, a centerline is automatically provided.
+  pronounced trend, a center line is automatically provided.
       > LineChart(Y)
   Also provided is a list of all the runs in the data.
 
@@ -466,10 +467,10 @@ function(topic=NULL, width=4.5, height=4.5) {
   Additional options are explained in the R help files for functions par,
   title, points and lines. 
 
-  Color themes are available with the colors option, which can be invoked
+  Color themes are available with the theme option, which can be invoked
   from a specific call to LineChart or system wide for all graphics output with
-  the function global Here all subsequent graphics output is in gray scale.
-      > global(colors=\"gray\")
+  the function style Here all subsequent graphics output is in gray scale.
+      > style(\"gray\")
       > LineChart(Y)
 
   Can replace the variable name with a list of multiple variables, such as
@@ -513,9 +514,9 @@ function(topic=NULL, width=4.5, height=4.5) {
   Here obtain a bubble plot of two categorical variables.
       > Plot(Gender, Dept)
 
-  The colors option specifies color themes. Here all subsequent
+  The theme option specifies color themes. Here all subsequent
   graphics are with the darkred color theme, no transparency.
-      > global(colors=\"darkred\", trans.fill.pt=0)
+      > style(\"darkred\", trans.pt.fill=0)
       > Plot(X, Y)"
 
   set.up.plot(1)
