@@ -39,15 +39,18 @@ function(lm.out, cook, cooks.cut,
   fit.ord <- fit[ord]
   res.ord <- res[ord]
 
+  par(bg=getOption("device.fill"))
+
   plot(fit.ord, res.ord, type="n", axes=FALSE, ann=FALSE)
 
   usr <- par("usr")
-  col.bg <- getOption("bg")
-  rect(usr[1], usr[3], usr[2], usr[4], col=col.bg, border="black")
+  rect(usr[1], usr[3], usr[2], usr[4],
+       col=getOption("bg.fill"), border=getOption("bg.stroke"))
 
-  col.grid <- getOption("grid")
-  abline(v=axTicks(1), col=col.grid, lwd=.5)
-  abline(h=axTicks(2), col=col.grid, lwd=.5)
+  abline(v=axTicks(1), col=getOption("grid.x.stroke"),
+         lwd=getOption("grid.lwd"), lty=getOption("grid.lty"))
+  abline(h=axTicks(2), col=getOption("grid.y.stroke"),
+         lwd=getOption("grid.lwd"), lty=getOption("grid.lty"))
 
   .axes(NULL, NULL, axTicks(1), axTicks(2),
         par("usr")[1], par("usr")[3], cex.axis=.8, col.axis="gray30")
@@ -58,16 +61,16 @@ function(lm.out, cook, cooks.cut,
   y.label <- "Residuals"
   .axlabs(x.label, y.label, main.lab, sub.lab, max.lbl.y=3, cex.lab=0.85) 
 
-  col.fill <- getOption("fill.pt")
-  col.stroke <- getOption("stroke.pt")
+  col.fill <- getOption("pt.fill")
+  col.stroke <- getOption("pt.stroke")
   points(fit.ord, res.ord, pch=21, col=col.stroke, bg=col.fill, cex=0.8)
 
-  abline(h=0, lty="dotted", lwd=1.5, col=getOption("fill.bar"))
-  lines(lowess(fit.ord, res.ord, f=.9), col=getOption("stroke.pt"))
+  abline(h=0, lty="dotted", lwd=1.5, col=getOption("bar.fill"))
+  lines(lowess(fit.ord, res.ord, f=.9), col=getOption("pt.stroke"))
   res.c <- res[which(cook>=cooks.cut)]
   fit.c <- fit[which(cook>=cooks.cut)]
   if (length(fit.c) > 0) {
-    col.out <- getOption("stroke.pt")
+    col.out <- getOption("pt.stroke")
     points(fit.c, res.c, col=col.out, pch=19)
     text(fit.c, res.c, names(fit.c), pos=1, cex=.8)
   }
