@@ -180,10 +180,10 @@ function(Y, Ynm, mu0=NULL, n=NULL, m=NULL, s=NULL, brief, bw1,
       plt.title[plt.i] <- paste("Sequentially Plotted Data for", Ynm)
 
       .lc.main(Y, type=NULL,
-        col.line=getOption("stroke.pt"), col.area=NULL, col.box="black",
-        col.stroke=getOption("stroke.pt"), 
-        col.fill=getOption("fill.bar"), shape.pts=21,
-        col.grid=getOption("grid"), col.bg=getOption("bg"),
+        col.line=getOption("pt.stroke"), col.area=NULL, col.box="black",
+        col.stroke=getOption("pt.stroke"), 
+        col.fill=getOption("bar.fill"), shape.pts=21,
+        col.bg=getOption("bg.fill"),
         cex.axis=0.75, col.axis="gray30", rotate.x=0, rotate.y=0, offset=.5,
         xy.ticks=TRUE, line.width=1.1,
         xlab=NULL, ylab=NULL, main=plt.title[plt.i], sub=NULL, cex=NULL,
